@@ -33,7 +33,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGES.
  *
- * $Id: if_athvar.h 3808 2008-07-18 21:50:53Z proski $
+ * $Id: if_athvar.h 3856 2008-09-02 21:30:32Z proski $
  */
 
 /*
@@ -537,7 +537,7 @@ struct ath_vap {
 	atomic_t av_beacon_alloc;       /* set to 1 when the next beacon needs
 					   to be recomputed */
 #else
-	unsigned int av_beacon_alloc;
+	unsigned long av_beacon_alloc;
 #endif
 };
 #define	ATH_VAP(_v)	((struct ath_vap *)(_v))
