@@ -29,7 +29,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: ieee80211.c 3787 2008-07-17 04:50:29Z proski $
+ * $Id: ieee80211.c 3902 2009-01-14 02:36:53Z proski $
  */
 #ifndef EXPORT_SYMTAB
 #define	EXPORT_SYMTAB
@@ -407,7 +407,7 @@ ieee80211_vap_setup(struct ieee80211com *ic, struct net_device *dev,
 #define	IEEE80211_C_OPMODE \
 	(IEEE80211_C_IBSS | IEEE80211_C_HOSTAP | IEEE80211_C_AHDEMO | \
 	 IEEE80211_C_MONITOR)
-	struct ieee80211vap *vap = dev->priv;
+	struct ieee80211vap *vap = netdev_priv(dev);
 	struct net_device *parent = ic->ic_dev;
 	int err;
 
@@ -1135,20 +1135,6 @@ ieee80211_mark_dfs(struct ieee80211com *ic, struct ieee80211_channel *ichan)
 }
 EXPORT_SYMBOL(ieee80211_mark_dfs);
 
-void
-ieee80211_dfs_test_return(struct ieee80211com *ic, u_int8_t ieeeChan)
-{
-	struct net_device *dev = ic->ic_dev;
-
-	/* Return to the original channel we were on before the test mute. */
-	if_printf(dev, "Returning to channel %d\n", ieeeChan);
-	printk(KERN_DEBUG "Returning to chan %d\n", ieeeChan);
-	ic->ic_chanchange_chan = ieeeChan;
-	ic->ic_chanchange_tbtt = IEEE80211_RADAR_CHANCHANGE_TBTT_COUNT;
-	ic->ic_flags |= IEEE80211_F_CHANSWITCH;
-}
-EXPORT_SYMBOL(ieee80211_dfs_test_return);
-
 void
 ieee80211_announce(struct ieee80211com *ic)
 {
@@ -1276,7 +1262,7 @@ media_status(enum ieee80211_opmode opmode, const struct ieee80211_channel *chan)
 static void
 ieee80211com_media_status(struct net_device *dev, struct ifmediareq *imr)
 {
-	struct ieee80211com *ic = dev->priv;	/* XXX */
+	struct ieee80211com *ic = netdev_priv(dev);	/* XXX */
 
 	imr->ifm_status = IFM_AVALID;
 	if (!TAILQ_EMPTY(&ic->ic_vaps))
@@ -1328,7 +1314,7 @@ media2mode(const struct ifmedia_entry *ime, enum ieee80211_phymode *mode)
 static int
 ieee80211com_media_change(struct net_device *dev)
 {
-	struct ieee80211com *ic = dev->priv;	/* XXX */
+	struct ieee80211com *ic = netdev_priv(dev);	/* XXX */
 	struct ieee80211vap *vap;
 	struct ifmedia_entry *ime = ic->ic_media.ifm_cur;
 	enum ieee80211_phymode newphymode;
@@ -1432,7 +1418,7 @@ checkrate(struct ieee80211com *ic, enum ieee80211_phymode mode, int rate)
 int
 ieee80211_media_change(struct net_device *dev)
 {
-	struct ieee80211vap *vap = dev->priv;
+	struct ieee80211vap *vap = netdev_priv(dev);
 	struct ieee80211com *ic = vap->iv_ic;
 	struct ifmedia_entry *ime = vap->iv_media.ifm_cur;
 	enum ieee80211_phymode newmode;
@@ -1470,7 +1456,7 @@ EXPORT_SYMBOL(ieee80211_media_change);
 void
 ieee80211_media_status(struct net_device *dev, struct ifmediareq *imr)
 {
-	struct ieee80211vap *vap = dev->priv;
+	struct ieee80211vap *vap = netdev_priv(dev);
 	struct ieee80211com *ic = vap->iv_ic;
 	enum ieee80211_phymode mode;
 	struct ieee80211_rateset *rs;
@@ -1676,7 +1662,7 @@ EXPORT_SYMBOL(ieee80211_media2rate);
 static struct net_device_stats *
 ieee80211_getstats(struct net_device *dev)
 {
-	struct ieee80211vap *vap = dev->priv;
+	struct ieee80211vap *vap = netdev_priv(dev);
 	struct net_device_stats *stats = &vap->iv_devstats;
 
 	/* XXX: Total guess as to what to count where */
@@ -1715,7 +1701,7 @@ ieee80211_change_mtu(struct net_device *dev, int mtu)
 static void
 ieee80211_set_multicast_list(struct net_device *dev)
 {
-	struct ieee80211vap *vap = dev->priv;
+	struct ieee80211vap *vap = netdev_priv(dev);
 	struct ieee80211com *ic = vap->iv_ic;
 	struct net_device *parent = ic->ic_dev;
 
