@@ -28,7 +28,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: ieee80211_scan.c 3341 2008-02-06 21:29:06Z mentor $
+ * $Id: ieee80211_scan.c 3787 2008-07-17 04:50:29Z proski $
  */
 #ifndef EXPORT_SYMTAB
 #define	EXPORT_SYMTAB
@@ -68,7 +68,7 @@ struct scan_state {
 	struct tasklet_struct ss_pwrsav;	/* sta ps ena tasklet */
 	struct timer_list ss_scan_timer;	/* scan timer */
 };
-#define	SCAN_PRIVATE(ss)	((struct scan_state *) ss)
+#define	SCAN_PRIVATE(_ss)	((struct scan_state *)(_ss))
 
 /*
  * Amount of time to go off-channel during a background
@@ -87,12 +87,12 @@ struct scan_state {
  * .5M units).
  */
 #define	SCAN_VALID_DEFAULT		60	/* scan cache valid age (secs) */
-#define	ROAM_RSSI_11A_DEFAULT		24	/* rssi threshold for 11a bss */
-#define	ROAM_RSSI_11B_DEFAULT		24	/* rssi threshold for 11b bss */
-#define	ROAM_RSSI_11BONLY_DEFAULT	24	/* rssi threshold for 11b-only bss */
-#define	ROAM_RATE_11A_DEFAULT		2*24	/* tx rate threshold for 11a bss */
-#define	ROAM_RATE_11B_DEFAULT		2*9	/* tx rate threshold for 11b bss */
-#define	ROAM_RATE_11BONLY_DEFAULT	2*5	/* tx rate threshold for 11b-only bss */
+#define	ROAM_RSSI_11A_DEFAULT		9	/* rssi threshold for 11a bss */
+#define	ROAM_RSSI_11G_DEFAULT		9	/* rssi threshold for 11g bss */
+#define	ROAM_RSSI_11BONLY_DEFAULT	9	/* rssi threshold for 11b-only bss */
+#define	ROAM_RATE_11A_DEFAULT		2 * 24	/* tx rate threshold for 11a bss */
+#define	ROAM_RATE_11G_DEFAULT		2 * 9	/* tx rate threshold for 11g bss */
+#define	ROAM_RATE_11BONLY_DEFAULT	2 * 5	/* tx rate threshold for 11b-only bss */
 
 static void scan_restart_pwrsav(unsigned long);
 static void scan_next(unsigned long);
@@ -142,10 +142,10 @@ ieee80211_scan_vattach(struct ieee80211vap *vap)
 	vap->iv_bgscanintvl = IEEE80211_BGSCAN_INTVAL_DEFAULT * HZ;
 	vap->iv_scanvalid = SCAN_VALID_DEFAULT * HZ;
 	vap->iv_roam.rssi11a = ROAM_RSSI_11A_DEFAULT;
-	vap->iv_roam.rssi11b = ROAM_RSSI_11B_DEFAULT;
+	vap->iv_roam.rssi11g = ROAM_RSSI_11G_DEFAULT;
 	vap->iv_roam.rssi11bOnly = ROAM_RSSI_11BONLY_DEFAULT;
 	vap->iv_roam.rate11a = ROAM_RATE_11A_DEFAULT;
-	vap->iv_roam.rate11b = ROAM_RATE_11B_DEFAULT;
+	vap->iv_roam.rate11g = ROAM_RATE_11G_DEFAULT;
 	vap->iv_roam.rate11bOnly = ROAM_RATE_11BONLY_DEFAULT;
 }
 
@@ -286,18 +286,18 @@ EXPORT_SYMBOL(ieee80211_scan_dump_channels);
 static void
 scan_restart_pwrsav(unsigned long arg)
 {
-	struct scan_state *ss = (struct scan_state *) arg;
+	struct scan_state *ss = (struct scan_state *)arg;
 	struct ieee80211vap *vap = ss->base.ss_vap;
 	struct ieee80211com *ic = vap->iv_ic;
 	int delay;
 
-	/* Handle PS stuff, if required. */
 	ieee80211_sta_pwrsave(vap, 1);
-	
-	/* Use an initial 1ms delay to ensure the null
+	/*
+	 * Use an initial 1ms delay to ensure the null
 	 * data frame has a chance to go out.
 	 * XXX: 1ms is a lot, better to trigger scan
-	 * on TX complete. */
+	 * on TX complete.
+	 */
 	delay = msecs_to_jiffies(1);
 	if (delay < 1)
 		delay = 1;
@@ -430,6 +430,18 @@ ieee80211_start_scan(struct ieee80211vap *vap, int flags, u_int duration,
 		IEEE80211_DPRINTF(vap, IEEE80211_MSG_SCAN,
 			"%s: %s scan already in progress\n", __func__,
 			ss->ss_flags & IEEE80211_SCAN_ACTIVE ? "active" : "passive");
+
+		/* If the running scanning has the flag SCAN_NOPICK set, but
+		 * the requested scan has not, then we update the running scan
+		 * flag. This is needed when wpa_supplicant is used with
+		 * ap_scan=1. Without it, the driver will never associate. */
+		if (((flags & IEEE80211_SCAN_NOPICK) == 0) &&
+		    (ss->ss_flags & IEEE80211_SCAN_NOPICK)) {
+			IEEE80211_DPRINTF(vap, IEEE80211_MSG_SCAN,
+					  "%s: clearing SCAN_NOPICK flag\n",
+					  __func__);
+			ss->ss_flags &= ~IEEE80211_SCAN_NOPICK;
+		}
 	}
 	
 	scanning = (ic->ic_flags & IEEE80211_F_SCAN);
@@ -630,7 +642,7 @@ static void
 scan_next(unsigned long arg)
 {
 #define	ISCAN_REP	(ISCAN_MINDWELL | ISCAN_START | ISCAN_DISCARD)
-	struct ieee80211_scan_state *ss = (struct ieee80211_scan_state *) arg;
+	struct ieee80211_scan_state *ss = (struct ieee80211_scan_state *)arg;
 	struct ieee80211vap *vap = ss->ss_vap;
 	struct ieee80211com *ic = vap->iv_ic;
 	struct ieee80211_channel *chan;
@@ -1007,16 +1019,16 @@ ieee80211_scan_dfs_action(struct ieee80211vap *vap,
 		 * $4.6.2.5.1 */
 		/* First, we count the usable channels */
 		count = 0;
-		curChanFlags = (ic->ic_bsschan->ic_flags) & 
+		curChanFlags = (ic->ic_bsschan->ic_flags) &
 			~(IEEE80211_CHAN_RADAR);
 		for (i = 0; i < ic->ic_nchans; i++) {
-			if ((ic->ic_channels[i].ic_ieee != 
+			if ((ic->ic_channels[i].ic_ieee !=
 						ic->ic_bsschan->ic_ieee) &&
 			    (ic->ic_channels[i].ic_flags == curChanFlags)) {
 				IEEE80211_DPRINTF(vap, IEEE80211_MSG_DOTH,
 						"%s: usable channel %3d "
 						"(%4d MHz)\n",
-						__func__, 
+						__func__,
 						ic->ic_channels[i].ic_ieee,
 						ic->ic_channels[i].ic_freq);
 				count ++;
@@ -1029,12 +1041,12 @@ ieee80211_scan_dfs_action(struct ieee80211vap *vap,
 
 			count = 0;
 			for (i = 0; i < ic->ic_nchans; i++) {
-				if ((ic->ic_channels[i].ic_ieee != 
+				if ((ic->ic_channels[i].ic_ieee !=
 				     ic->ic_bsschan->ic_ieee) &&
-				    (ic->ic_channels[i].ic_flags == 
+				    (ic->ic_channels[i].ic_flags ==
 				     curChanFlags)) {
 					if (count++ == chanStart) {
-						new_channel = 
+						new_channel =
 							&ic->ic_channels[i];
 						break;
 					}
@@ -1045,16 +1057,16 @@ ieee80211_scan_dfs_action(struct ieee80211vap *vap,
 		if (new_channel != NULL)
 			IEEE80211_DPRINTF(vap, IEEE80211_MSG_DOTH,
 					"%s: new random channel found %3d "
-					"(%4d MHz)\n", __func__, 
-					new_channel->ic_ieee, 
+					"(%4d MHz)\n", __func__,
+					new_channel->ic_ieee,
 					new_channel->ic_freq);
 	}
 
 	if (!new_channel) {
 		/* Search for the first channel with no radar detected */
 		int n = 0;
-		for(n = 0; n < ic->ic_nchans; n++) {
-			if (0 == (ic->ic_channels[n].ic_flags & 
+		for (n = 0; n < ic->ic_nchans; n++) {
+			if (0 == (ic->ic_channels[n].ic_flags &
 						IEEE80211_CHAN_RADAR)) {
 				new_channel = &ic->ic_channels[n];
 				break;
@@ -1075,7 +1087,7 @@ ieee80211_scan_dfs_action(struct ieee80211vap *vap,
 					  new_channel->ic_freq);
 
 			ic->ic_chanchange_chan = new_channel->ic_ieee;
-			ic->ic_chanchange_tbtt = 
+			ic->ic_chanchange_tbtt =
 				IEEE80211_RADAR_CHANCHANGE_TBTT_COUNT;
 			ic->ic_flags |= IEEE80211_F_CHANSWITCH;
 		} else {
